@@ -7,8 +7,7 @@ from llmling.cli.utils import format_output, get_command_help
 from llmling.config.store import config_store
 
 
-CONFIG_HELP = "Config file management commands."
-help_text = get_command_help(CONFIG_HELP)
+help_text = get_command_help("Config file management commands.")
 config_cli = t.Typer(help=help_text, no_args_is_help=True)
 
 
@@ -84,25 +83,37 @@ def list_configs(
 @config_cli.command("init")
 def init_config(
     output: str = t.Argument(help="Path to write configuration file"),
+    interactive: bool = t.Option(
+        False,
+        "--interactive/--no-interactive",
+        help="Use interactive configuration wizard",
+    ),
 ):
     """Initialize a new configuration file with basic settings.
 
-    Creates a new configuration file at the specified path using the basic template.
-    The basic template includes a text resource, a browser tool, and example prompts
-    that work out of the box.
+    Creates a new configuration file at the specified path. Use --interactive
+    for a guided setup process.
     """
-    import shutil
+    from promptantic import ModelGenerator
 
-    from llmling import config_resources
+    from llmling import Config
 
-    # Copy our basic template to the output path
-    shutil.copy2(config_resources.BASIC_CONFIG, output)
-    print(f"Created configuration file: {output}")
-    print("\nTry these commands:")
-    print("  llmling resource list")
-    print("  llmling tool call open_url url=https://github.com")
-    print("  llmling prompt show greet")
-    print("  llmling prompt show get_user")
+    if interactive:
+        generator = ModelGenerator()
+        config = generator.populate(Config)
+        config.save(output)
+        print(f"Created configuration file: {output}")
+    else:
+        import shutil
+
+        from llmling import config_resources
+
+        shutil.copy2(config_resources.BASIC_CONFIG, output)
+        print(f"Created configuration file: {output}")
+        print("\nTry these commands:")
+        print("  llmling resource list")
+        print("  llmling tool call open_url url=https://github.com")
+        print("  llmling prompt show greet")
 
 
 @config_cli.command("show")
