@@ -8,7 +8,6 @@ import os  # noqa: TC003
 from typing import Annotated, Any, Literal, Self
 import warnings
 
-import logfire
 from pydantic import (
     BaseModel,
     ConfigDict,
@@ -17,57 +16,45 @@ from pydantic import (
     field_validator,
     model_validator,
 )
-import upath
-import yamling
 
 from llmling import config_resources
+from llmling.config.base import ConfigModel
 from llmling.core import exceptions
 from llmling.core.log import get_logger
 from llmling.core.typedefs import ProcessingStep  # noqa: TC001
 from llmling.processors.base import ProcessorConfig  # noqa: TC001
 from llmling.prompts.models import PromptType  # noqa: TC001
 from llmling.tools.toolsets import ToolSet
-from llmling.utils import importing
-from llmling.utils.importing import import_callable
+from llmling.utils.importing import import_callable, import_class
 from llmling.utils.paths import guess_mime_type
 
 
-ResourceType = Literal["path", "text", "cli", "source", "callable", "image"]
+ResourceType = Literal["path", "text", "cli", "source", "callable"]
 LogLevel = Literal["DEBUG", "INFO", "WARNING", "ERROR", "CRITICAL"]
 
 logger = get_logger(__name__)
 
 
-class ConfigModel(BaseModel):
-    """Base class for all LLMling configuration models.
+class LLMCapabilitiesConfig(ConfigModel):
+    """Configuration for LLM system capabilities."""
 
-    Provides:
-    - Common Pydantic settings
-    - YAML serialization
-    - Basic merge functionality
-    """
+    load_resource: bool = False
+    """Whether the LLM can load and access resource content."""
 
-    model_config = ConfigDict(
-        frozen=True,
-        extra="forbid",
-        use_attribute_docstrings=True,
-    )
+    get_resources: bool = False
+    """Whether the LLM can discover available resources."""
 
-    def merge(self, other: Self) -> Self:
-        """Merge with another instance by overlaying its non-None values."""
-        from llmling.config.utils import merge_models
+    install_package: bool = False
+    """Whether the LLM can install new Python packages for future tools."""
 
-        return merge_models(self, other)
+    register_tool: bool = False
+    """Whether the LLM can register importable functions as new tools."""
 
-    def to_yaml(self) -> str:
-        """Serialize to YAML string."""
-        return yamling.dump_yaml(self.model_dump(exclude_none=True))
+    register_code_tool: bool = False
+    """Whether the LLM can create new tools from provided Python code."""
 
-    @classmethod
-    def from_yaml(cls, content: str) -> Self:
-        """Create from YAML string."""
-        data = yamling.load_yaml(content)
-        return cls.model_validate(data)
+    chain_tools: bool = False
+    """Whether the LLM gains capability to chain multiple tool calls into one."""
 
 
 class Jinja2Config(ConfigModel):
@@ -141,8 +128,6 @@ class Jinja2Config(ConfigModel):
         """
         import jinja2
 
-        from llmling.utils import importing
-
         # Start with basic string/bool config items
         kwargs = self.model_dump(exclude={"undefined", "filters", "tests"})
 
@@ -156,13 +141,10 @@ class Jinja2Config(ConfigModel):
 
         try:
             # Import filters and tests (must be callables)
-            kwargs["filters"] = {
-                name: importing.import_callable(path)
-                for name, path in self.filters.items()
-            }
-            kwargs["tests"] = {
-                name: importing.import_callable(path) for name, path in self.tests.items()
-            }
+            filters = {name: import_callable(path) for name, path in self.filters.items()}
+            kwargs["filters"] = filters
+            tests = {name: import_callable(path) for name, path in self.tests.items()}
+            kwargs["tests"] = tests
         except Exception as exc:
             msg = f"Failed to import Jinja2 filters/tests: {exc}"
             raise ValueError(msg) from exc
@@ -195,22 +177,19 @@ class GlobalSettings(ConfigModel):
     """Explicitely use uv for package installation / management """
 
     log_level: LogLevel = "INFO"
-    """Log level to use for the server"""
+    """Log level for LLMling core."""
 
     jinja_environment: Jinja2Config = Field(default_factory=Jinja2Config)
     """Jinja2 environment configuration"""
 
-    enable_resource_tools: bool = True
-    """Whether to register tools for resource loading/listing"""
-
-    enable_tool_management: bool = True
-    """Whether to register tools for dynamic tool registration and package management"""
+    llm_capabilities: LLMCapabilitiesConfig = Field(default_factory=LLMCapabilitiesConfig)
+    """Control which system capabilities are exposed to LLMs."""
 
 
 class BaseResource(BaseModel):
     """Base class for all resource types."""
 
-    resource_type: str = Field(init=False)
+    type: str = Field(init=False)
     """Type identifier for this resource."""
 
     description: str = ""
@@ -225,8 +204,27 @@ class BaseResource(BaseModel):
     watch: WatchConfig | None = None
     """Configuration for file system watching, if supported."""
 
+    name: str | None = Field(None, exclude=True)
+    """Technical identifier (automatically set from config key during registration)."""
+
+    # TODO: proper extra="forbid" for all subclasses.
     model_config = ConfigDict(frozen=True, use_attribute_docstrings=True)
 
+    def validate_resource(self) -> list[str]:
+        """Validate resource at runtime.
+
+        This validation is intentionally separated from Pydantic's model validation
+        to handle:
+        - Remote resources and URLs
+        - Template/placeholder paths that don't exist during config loading
+        - Resources that may become available after config loading
+        - Validation of actual resource availability separate from config structure
+
+        Returns:
+            List of validation warnings (empty if all valid)
+        """
+        return []
+
     @property
     def supports_watching(self) -> bool:
         """Whether this resource instance supports watching."""
@@ -240,6 +238,10 @@ class BaseResource(BaseModel):
         """Whether this resource supports URI templates."""
         return False  # Default: resources are static
 
+    def get_watch_path(self) -> str | None:
+        """Get the path to watch if this resource supports watching."""
+        return None
+
     @property
     def mime_type(self) -> str:
         """Get the MIME type for this resource.
@@ -253,7 +255,7 @@ class BaseResource(BaseModel):
 class PathResource(BaseResource):
     """Resource loaded from a file or URL."""
 
-    resource_type: Literal["path"] = Field(default="path", init=False)
+    type: Literal["path"] = Field(default="path", init=False)
     """Discriminator field identifying this as a path-based resource."""
 
     path: str | os.PathLike[str]
@@ -262,9 +264,24 @@ class PathResource(BaseResource):
     watch: WatchConfig | None = None
     """Configuration for watching the file for changes."""
 
+    def validate_resource(self) -> list[str]:
+        """Check if path exists for local files."""
+        import upath
+
+        warnings = []
+        path = upath.UPath(self.path)
+        prefixes = ("http://", "https://")
+
+        if not path.exists() and not path.as_uri().startswith(prefixes):
+            warnings.append(f"Resource path not found: {path}")
+
+        return warnings
+
     @property
     def supports_watching(self) -> bool:
         """Whether this resource instance supports watching."""
+        import upath
+
         path = upath.UPath(self.path)
         if not path.exists():
             msg = f"Cannot watch non-existent path: {self.path}"
@@ -272,6 +289,10 @@ class PathResource(BaseResource):
             return False
         return True
 
+    def get_watch_path(self) -> str | None:
+        """Get the path to watch."""
+        return str(self.path) if self.supports_watching else None
+
     @model_validator(mode="after")
     def validate_path(self) -> PathResource:
         """Validate that the path is not empty."""
@@ -293,7 +314,7 @@ class PathResource(BaseResource):
 class TextResource(BaseResource):
     """Raw text resource."""
 
-    resource_type: Literal["text"] = Field(default="text", init=False)
+    type: Literal["text"] = Field(default="text", init=False)
     """Discriminator field identifying this as a text-based resource."""
 
     content: str
@@ -321,7 +342,7 @@ class TextResource(BaseResource):
 class CLIResource(BaseResource):
     """Resource from CLI command execution."""
 
-    resource_type: Literal["cli"] = Field(default="cli", init=False)
+    type: Literal["cli"] = Field(default="cli", init=False)
     """Discriminator field identifying this as a CLI-based resource."""
 
     command: str | TypingSequence[str]
@@ -355,7 +376,7 @@ class CLIResource(BaseResource):
 class RepositoryResource(BaseResource):
     """Git repository content."""
 
-    resource_type: Literal["repository"] = Field("repository", init=False)
+    type: Literal["repository"] = Field("repository", init=False)
     repo_url: str
     """URL of the git repository."""
 
@@ -374,11 +395,17 @@ class RepositoryResource(BaseResource):
     password: SecretStr | None = None
     """Optional password for authentication."""
 
+    def validate_resource(self) -> list[str]:
+        warnings = []
+        if self.user and not self.password:
+            warnings.append(f"Repository {self.repo_url} has user but no password")
+        return warnings
+
 
 class SourceResource(BaseResource):
     """Resource from Python source code."""
 
-    resource_type: Literal["source"] = Field(default="source", init=False)
+    type: Literal["source"] = Field(default="source", init=False)
     """Discriminator field identifying this as a source code resource."""
 
     import_path: str
@@ -402,7 +429,7 @@ class SourceResource(BaseResource):
 class CallableResource(BaseResource):
     """Resource from executing a Python callable."""
 
-    resource_type: Literal["callable"] = Field(default="callable", init=False)
+    type: Literal["callable"] = Field(default="callable", init=False)
     """Discriminator field identifying this as a callable-based resource."""
 
     import_path: str
@@ -426,58 +453,10 @@ class CallableResource(BaseResource):
         return bool(sig.parameters)
 
 
-class ImageResource(BaseResource):
-    """Resource for image input."""
-
-    resource_type: Literal["image"] = Field(default="image", init=False)
-    """Discriminator field identifying this as an image resource."""
-
-    path: str
-    """Path or URL to the image file."""
-
-    alt_text: str | None = None
-    """Alternative text description of the image."""
-
-    watch: WatchConfig | None = None
-    """Configuration for watching the image file for changes."""
-
-    @property
-    def supports_watching(self) -> bool:
-        """Whether this resource instance supports watching."""
-        return True
-
-    @model_validator(mode="before")
-    @classmethod
-    def validate_path(cls, data: dict[str, Any]) -> dict[str, Any]:
-        """Validate that path is not empty."""
-        if isinstance(data, dict) and not data.get("path"):
-            msg = "Path cannot be empty for image resource"
-            raise ValueError(msg)
-        return data
-
-    @property
-    def mime_type(self) -> str:
-        """Get MIME type based on file extension or default to image/jpeg."""
-        try:
-            mime = guess_mime_type(self.path)
-            # If it's an image type, return it
-            if mime.startswith("image/"):
-                return mime
-            # If not an image type or unknown, fall back to jpeg
-        except Exception:  # noqa: BLE001
-            return "image/jpeg"
-        else:
-            return "image/jpeg"
-
-
-Resource = (
-    PathResource
-    | TextResource
-    | CLIResource
-    | SourceResource
-    | CallableResource
-    | ImageResource
-)
+Resource = Annotated[
+    PathResource | TextResource | CLIResource | SourceResource | CallableResource,
+    Field(discriminator="type"),
+]
 
 
 class WatchConfig(ConfigModel):
@@ -550,7 +529,7 @@ class CustomToolsetConfig(BaseToolsetConfig):
     def validate_import_path(cls, v: str) -> str:
         # v is already confirmed to be a str here
         try:
-            cls = importing.import_class(v)
+            cls = import_class(v)
             if not issubclass(cls, ToolSet):
                 msg = f"{v} must be a ToolSet class"
                 raise ValueError(msg)  # noqa: TRY004, TRY301
@@ -597,7 +576,7 @@ class Config(ConfigModel):
     model_config = ConfigDict(
         frozen=True,
         arbitrary_types_allowed=True,
-        extra="forbid",
+        extra="allow",  # extra fields used by the server for example.
         use_attribute_docstrings=True,
     )
 
@@ -644,14 +623,7 @@ class Config(ConfigModel):
                     msg = f"Processor {processor.name!r} not found"
                     raise ValueError(msg)
 
-    def model_dump_yaml(self) -> str:
-        """Dump configuration to YAML string."""
-        import yamling
-
-        return yamling.dump_yaml(self.model_dump(exclude_none=True))
-
     @classmethod
-    @logfire.instrument("Loading configuration from {path}")
     def from_file(cls, path: str | os.PathLike[str]) -> Self:
         """Load configuration from YAML file.
 
@@ -667,6 +639,8 @@ class Config(ConfigModel):
         Raises:
             ConfigError: If loading fails
         """
+        import yamling
+
         logger.debug("Loading configuration from %s", path)
 
         try:
@@ -686,8 +660,16 @@ class Config(ConfigModel):
             msg = f"Failed to validate configuration from {path}"
             raise exceptions.ConfigError(msg) from exc
         else:
-            msg = "Loaded raw configuration: version=%s, resources=%d"
-            logger.debug(msg, config.version, len(config.resources))
+            logger.debug("Loaded raw configuration:")
+            msg = "version=%s, resources=%d, tools=%d, toolsets=%d, prompts=%d"
+            logger.debug(
+                msg,
+                config.version,
+                len(config.resources),
+                len(config.tools),
+                len(config.toolsets),
+                len(config.prompts),
+            )
             return config
 
 
