@@ -6,15 +6,16 @@ import inspect
 import os  # noqa: TC003
 from typing import TYPE_CHECKING, Annotated, Any, Literal, get_type_hints
 
-from docstring_parser import parse as parse_docstring
 from pydantic import BaseModel, ConfigDict, Field, ImportString
-import upath
 
 from llmling.completions import CompletionFunction  # noqa: TC001
+from llmling.core.log import get_logger
 from llmling.core.typedefs import MessageContent, MessageRole
 from llmling.utils import calling, importing
 
 
+logger = get_logger(__name__)
+
 if TYPE_CHECKING:
     from collections.abc import Callable, Mapping
 
@@ -31,7 +32,7 @@ class PromptParameter(BaseModel):
     required: bool = False
     """Whether this argument must be provided when formatting the prompt."""
 
-    type_hint: Any = str
+    type_hint: ImportString = Field(default="str")
     """Type annotation for the argument, defaults to str."""
 
     default: Any | None = None
@@ -88,6 +89,13 @@ class BasePrompt(BaseModel):
 
     model_config = ConfigDict(extra="forbid", use_attribute_docstrings=True)
 
+    def get_messages(self) -> list[PromptMessage]:
+        """Get the messages for this prompt."""
+        if not hasattr(self, "messages"):
+            msg = f"{self.__class__.__name__} must implement 'messages' attribute"
+            raise NotImplementedError(msg)
+        return self.messages  # pyright: ignore
+
     def validate_arguments(self, provided: dict[str, Any]) -> None:
         """Validate that required arguments are provided."""
         required = {arg.name for arg in self.arguments if arg.required}
@@ -199,9 +207,24 @@ class DynamicPrompt(BasePrompt):
             PromptMessage(role="user", content=user_content),
         ]
 
+    def get_completion_functions(self) -> dict[str, CompletionFunction]:
+        """Resolve completion function import paths and return a completion fn dict."""
+        completion_funcs: dict[str, CompletionFunction] = {}
+        if not self.completions:
+            return {}
+        for arg_name, import_path in self.completions.items():
+            try:
+                func = importing.import_callable(import_path)
+                completion_funcs[arg_name] = func
+            except ValueError:
+                msg = "Failed to import completion function for %s: %s"
+                logger.warning(msg, arg_name, import_path)
+        return completion_funcs
+
     async def format(
         self, arguments: dict[str, Any] | None = None
     ) -> list[PromptMessage]:
+        """Format this prompt with given arguments."""
         args = arguments or {}
         self.validate_arguments(args)
 
@@ -246,6 +269,8 @@ class DynamicPrompt(BasePrompt):
         Raises:
             ValueError: If callable cannot be imported or is invalid
         """
+        from docstring_parser import parse as parse_docstring
+
         completions = completions or {}
         # Import if string path provided
         if isinstance(fn, str):
@@ -325,29 +350,31 @@ class FilePrompt(BasePrompt):
     @property
     def messages(self) -> list[PromptMessage]:
         """Get messages from file content."""
-        content = upath.UPath(self.path).read_text()
+        import upath
+
+        content = upath.UPath(self.path).read_text("utf-8")
 
         match self.fmt:
             case "text":
                 # Simple text format - whole file as user message
                 msg = MessageContent(type="text", content=content)
-                return [PromptMessage(role="user", content=msg)]
             case "markdown":
                 # TODO: Parse markdown sections into separate messages
                 msg = MessageContent(type="text", content=content)
-                return [PromptMessage(role="user", content=msg)]
             case "jinja2":
                 # Raw template - will be formatted during format()
                 msg = MessageContent(type="text", content=content)
-                return [PromptMessage(role="user", content=msg)]
             case _:
                 msg = f"Unsupported format: {self.fmt}"
                 raise ValueError(msg)
+        return [PromptMessage(role="user", content=msg)]
 
     async def format(
         self, arguments: dict[str, Any] | None = None
     ) -> list[PromptMessage]:
         """Format the file content with arguments."""
+        import upath
+
         args = arguments or {}
         self.validate_arguments(args)
 
@@ -356,7 +383,7 @@ class FilePrompt(BasePrompt):
             if arg.name not in args and not arg.required:
                 args[arg.name] = arg.default if arg.default is not None else ""
 
-        content = upath.UPath(self.path).read_text()
+        content = upath.UPath(self.path).read_text("utf-8")
 
         if self.fmt == "jinja2":
             # Use jinja2 for template formatting
