@@ -1,11 +1,9 @@
 """File system watching for resources."""
 
-from llmling.resources.watching.models import WatchConfig
 from llmling.resources.watching.watcher import ResourceWatcher
 from llmling.resources.watching.utils import load_patterns
 
 __all__ = [
     "ResourceWatcher",
-    "WatchConfig",
     "load_patterns",
 ]
