@@ -1,4 +1,4 @@
-"""Source code context loader."""
+"""Utilities for importing callables and classes from dotted paths."""
 
 from __future__ import annotations
 
@@ -23,11 +23,7 @@ def get_module_source(
     try:
         module = importlib.import_module(import_path)
         sources = list(
-            _get_sources(
-                module,
-                recursive=recursive,
-                include_tests=include_tests,
-            )
+            _get_sources(module, recursive=recursive, include_tests=include_tests)
         )
         return "\n\n# " + "-" * 40 + "\n\n".join(sources)
 
